@@ -15,6 +15,7 @@
 #'   "response" scale (Same as for [stats::predict.glm()]).
 #' @param return_mcmc Logical. Should the full MCMC draws be returned for the
 #'   predictions?
+#' @param offset Optional offset vector to be used in prediction.
 #' @param iter Number of MCMC iterations to draw. Defaults to all.
 #' @param ... Ignored currently
 #'
@@ -68,7 +69,7 @@
 #' )
 #' pred_grid$prediction <- predict(m,
 #'   newdata = pred_grid, type = "response", iter = 100,
-#'   estimate_method = "median"
+#'   estimate_method = "median", offset = rep(0, nrow(pred_grid))
 #' )$estimate
 #'
 #' ggplot(pred_grid, aes(lon, lat, fill = prediction)) +
@@ -127,6 +128,7 @@ predict.glmmfields <- function(object, newdata = NULL,
                                interval = c("confidence", "prediction"),
                                type = c("link", "response"),
                                return_mcmc = FALSE,
+                               offset = NULL,
                                iter = "all", ...) {
   estimate_method <- match.arg(estimate_method)
   interval <- match.arg(interval)
@@ -143,6 +145,12 @@ predict.glmmfields <- function(object, newdata = NULL,
 
   obs_model <- object$obs_model
 
+  if (is.null(newdata)) offset <- object$offset
+  if (is.null(offset) && !is.null(newdata)) offset <- rep(0, nrow(newdata))
+  if (!is.null(newdata) && !is.null(object$offset)) {
+    if (is.null(offset)) stop("Missing `offset` argument.", call. = FALSE)
+  }
+
   # newdata is df with time, y, lon, lat
   # if null, defaults to data used to fit model
   if (is.null(newdata)) newdata <- object$data
@@ -265,6 +273,8 @@ predict.glmmfields <- function(object, newdata = NULL,
   # generate (1) confidence intervals on mean or (2) prediction intervals
   # including obs error
 
+  pred_values <- pred_values + offset
+
   if (type == "response") {
     # gamma or NB2 or poisson:
     if (obs_model %in% c(0, 2, 5, 6)) pred_values <- exp(pred_values)
